@@ -6,7 +6,7 @@ use Carp;
 use Moo;
 use Types::Standard qw/Str Num Int ArrayRef/;
 
-our $VERSION = '0.0.3'; # VERSION
+our $VERSION = '0.0.4'; # VERSION
 # ABSTRACT: Statistics::Cook - calculate cook distance of Least squares line fit
 
 
@@ -165,15 +165,16 @@ sub cooks_distance {
   return @cooks;
 }
 
+
 sub N {
-  my ($self, $num) = @_;
-  my $n = shift || 50;
+  my ($self, $num, $N) = @_;
+  $N ||= 50;
   my @nums = sort { $a <=> $b } @$num;
   my $sum = sum(@nums);
   my $tmp = 0;
   for my $i (0..$#nums) {
     $tmp += $nums[$i];
-    return ($nums[$i], $i+1) if ($tmp > $sum * $n / 100);
+    return ($nums[$i], $i+1) if ($tmp > $sum * $N / 100);
   }
 }
 
@@ -191,7 +192,7 @@ Statistics::Cook - Statistics::Cook - calculate cook distance of Least squares l
 
 =head1 VERSION
 
-version 0.0.3
+version 0.0.4
 
 =head1 SYNOPSIS
 
